--- 模块功能：GPIO控制
-- @author openLuat
-- @module EWWJ.charge
-- @license MIT
-- @copyright openLuat
-- @release 2018.10.17
module(...,package.seeall)
require"pins"
require"nvm"
require"mqttTask"

--最大时间20天，防止定时器超过int32最大值
local maxTime = 1728000

--停止继电器
local function relayStop()
    sys.timerStopAll(relayStop)
    sys.timerStopAll(relayLong)
    log.info("pincfg.relay","stop")
    nvm.set("relayEnd",0)
    setRelay(0)--关闭继电器
    --上报正常关闭继电器的报文
    local payload,topic = dataPack.relayStop(true)
    mqttTask.insertMsg(topic,payload,0)
end

--超长时间继续开继电器
local function relayLong()
    sys.timerStopAll(relayLong)
    local relayEnd = nvm.get("relayEnd") or 0
    if relayEnd > os.time() then
        relayStart(relayEnd - os.time(),nvm.get("relayType") or 0)
        log.info("pincfg.relay","continue open")
    else
        relayStop()
    end
end

--开始继电器
function relayStart(worktime,type)
    log.info("pincfg.relay","Start")
    --检测到开启时间为0，直接关闭
    if worktime <= 0 then relayStop() return true end
    --如果正在延时，退出，类型5直接刷新，无视正在运行
    if type ~= 5 and sys.timerIsActive(relayStop) or sys.timerIsActive(relayLong) then return false end
    sys.timerStopAll(relayStop)
    sys.timerStopAll(relayLong)
    log.info("pincfg.relay","work",worktime,type)
    nvm.set("relayEnd",os.time()+worktime)
    nvm.set("relayType",type)
    setRelay(1)--开启继电器
    if worktime < maxTime then--小于设定的最大时间
        sys.timerStart(relayStop,worktime*1000)
    else
        sys.timerStart(relayLong,maxTime*1000)
    end
    return true
end

--是否检测投币
local coinCheck = true
function coinCheckState()
    return coinCheck
end
--停止检测投币一段时间
function closeCheck(delay)
    sys.taskInit(function ()
        coinCheck = false
        log.info("pincfg.closeCheck","stop check")
        if not sys.waitUntil("PLUSE_FAIL",delay) then
            --多等一段时间等看门狗芯片反馈
            sys.waitUntil("PLUSE_SENT_UART",2000)
        end
        coinCheck = true
        log.info("pincfg.closeCheck","start check")
    end)
end
--投币反馈
local function coinChange(msg)
    log.info("pincfg.coinChange",msg)
    sys.publish("PLUSE_SENT")
    if not coinCheck then return end
    --上升沿中断
    if msg==cpu.INT_GPIO_POSEDGE then
        --空着
    --下降沿中断
    else
        local coinTemp = nvm.get("coin") or 0
        nvm.set("coin",coinTemp+1)
        log.info("pincfg.coinChange","add coin,now:",coinTemp+1)
    end
end

--配置投币检测io口
local coinPin = _G.moduleType == 2 and pio.P0_29 or pio.P1_27
local getCoin = pins.setup(coinPin,coinChange)

--配置继电器io口
local relayPin = _G.moduleType == 2 and pio.P0_7 or pio.P1_23
setRelay = pins.setup(relayPin,0)--默认输出低电平


